{{/*
Полное имя приложения создается по правилу <имя helm-charts>-<имя инстанса>
<Имя инстанса> = Release.Name
*/}}
{{- define "graphite.fullname" -}}
{{- printf "%s-%s" .Chart.Name .Release.Name | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Common labels
*/}}
{{- define "graphite.labels" -}}
app.kubernetes.io/instance: {{ .Release.Name }}
app.kubernetes.io/name: {{ .Chart.Name }}
{{- if .Chart.AppVersion }}
app.kubernetes.io/version: {{ .Chart.AppVersion | quote }}
{{- end }}
app.kubernetes.io/component: graphite
app.kubernetes.io/managed-by: {{ .Release.Service }}
{{- end }}

{{/*
Create chart name and version as used by the chart label.
*/}}
{{- define "graphite.chart" -}}
{{- printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Selector labels
*/}}
{{- define "graphite.selectorLabels" -}}
app.kubernetes.io/instance: {{ .Release.Name }}
app: {{ include "graphite.fullname" . }}
run: graphite
{{- end }}

{{/*
Return  the proper Storage Class
*/}}
{{- define "graphite.storageClass" -}}
  {{- if .Values.persistence.storageClass -}}
      {{- if (eq "-" .Values.persistence.storageClass) -}}
          {{- printf "storageClassName: \"\"" -}}
      {{- else }}
          {{- printf "storageClassName: %s" .Values.persistence.storageClass -}}
      {{- end -}}
  {{- end -}}
{{- end -}}

{{/*
Имя configMap для graphite
*/}}
{{- define "graphite.config" -}}
{{- printf "%s-%s-%s" "graphite" .Chart.Name "config" | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}